@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.104-4-ge344bb2
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.105-6-g4ad06e8
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use Moose;
 with
@@ -211,7 +211,7 @@ sub configure
         qw(MetaYAML MetaJSON Readme Manifest),
         [ 'License'             => { ':version' => '5.038', filename => $self->licence } ],
         [ 'GenerateFile::ShareDir' => 'generate CONTRIBUTING' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING', has_xs => $has_xs } ],
-        'InstallGuide',
+        [ 'InstallGuide'        => { ':version' => '1.200005' } ],
 
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
             script_finder => [qw(:PerlExecFiles @Author::ETHER/Examples)] } ],
@@ -223,7 +223,7 @@ sub configure
         [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
         'PodSyntaxTests',
         'PodCoverageTests',
-        [ 'Test::PodSpelling'   => { ':version' => '2.006001', stopwords => ['irc'] } ],
+        [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
         [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
@@ -446,7 +446,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.105
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -521,6 +521,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     -filename = CONTRIBUTING
     has_xs = <dynamically-determined flag>
     [InstallGuide]
+    :version = 1.200005
 
     [Test::Compile]
     :version = 2.039
@@ -555,6 +556,9 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [PodSyntaxTests]
     [PodCoverageTests]
     [Test::PodSpelling]
+    :version = 2.006003
+    stopwords = irc
+
     ;[Test::Pod::LinkCheck]     many outstanding bugs
     [Test::Pod::No404s]
     :version = 1.002
