@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -167,7 +167,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.105
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -228,7 +228,8 @@ following F<weaver.ini>, minus some optimizations:
 
     [Region / postlude]
 
-    [GenerateSection / SUPPORT]
+    [GenerateSection / generate SUPPORT]
+    title = SUPPORT
     main_module_only = 0
     text = <template>
     [AllowOverride / allow override SUPPORT]
@@ -260,6 +261,7 @@ This is also equivalent (other than section ordering) to:
     command = type
 
     [GenerateSection / generate SUPPORT]
+    title = SUPPORT
     main_module_only = 0
     text = <template>
     [AllowOverride / allow override SUPPORT]
